<?php

/**
 * @file
 * AvaTax Sales Order Processing - sample include
 */

/**
 * Commit and Void orders in the AvaTax system.
 *
 * @param object $order
 *   The current order object.
 *
 * @return bool
 *   FALSE if the status could not be changed or AvaTax updated
 */

/**
 * Implements hook_order().
 */
function uc_avatax_order($op, &$arg1, $arg2) {
  switch ($op) {
    case 'can_update':
      if (uc_avatax_check_address($arg1) != TRUE){
        break;
      }

      $new_state = uc_order_status_data($arg2, 'state'); 

      // Commit AvaTax transaction
      if ($new_state == 'completed') {
	    _uc_avatax_update($arg1, 'commit');
      }

      // Void AvaTax transaction when cancelled.
      if ($new_state == 'canceled') {
	    _uc_avatax_update($arg1, 'cancel');
      }
    
    // Void AvaTax transaction when order deleted from Ubercart
    case 'delete':
      if (arg(0) == 'admin' && arg(1) == 'store' && arg(2) == 'orders' && is_numeric(arg(3)) && arg(4) == 'delete' ) {
        _uc_avatax_update($arg1, 'cancel');
      }
      else {
        break;
      }
  }
}

/**
 * Send Commit/Cancel operation to Avatax.
 */
function _uc_avatax_update($order, $type = 'commit') {
  // Get Company code and Company Use Mode.
  $company_code = (variable_get('uc_avatax_company_code', ''));
  $use_mode = (variable_get('uc_avatax_use_mode', UC_AVATAX_DEVELOPMENT_MODE));
  $product_version = variable_get('uc_avatax_product_version', UC_AVATAX_TRIAL_VERSION);
  $account_no = variable_get('uc_avatax_account', '');
  $license_key = variable_get('uc_avatax_license', '');

  if ($use_mode == UC_AVATAX_DEVELOPMENT_MODE) {
    $base_url = 'https://development.avalara.net/1.0';
  }
  elseif ($use_mode == UC_AVATAX_PRODUCTION_MODE) {
    $base_url = 'https://rest.avalara.net/1.0';
  }
  
  switch ($type) {
    case 'commit':
	  uc_avatax_retrieve_sales_tax($order, TRUE);
      break;

    case 'cancel':
	  $doc_code_prefix = 'uc';
      $body = array(
        'Client' => 'Ubercart2x-adTumblerInc,4.0',
        'DocCode' => $doc_code_prefix . '-' . $order->order_id,
        'CompanyCode' => $company_code,
        'DocType' => 'SalesInvoice',
        'CancelCode' => 'DocVoided',
      );
      $response = uc_avatax_post('/tax/cancel', $body);
      if (is_array($response) && $response['body']) {
        $result = $response['body'];
        if (isset($result['CancelTaxResult']['ResultCode']) && $result['CancelTaxResult']['ResultCode'] != 'Success') {
          foreach ($result['CancelTaxResult']['Messages'] as $msg) {
            drupal_set_message(t('AvaTax error: %msg - %source - %summary', array(
              '%msg' => $msg['Severity'],
              '%source' => $msg['Source'],
              '%summary' => $msg['Summary'],
                    )), 'error');
          }
          watchdog('uc_avatax', 'Failed to void order @id !req !resp', array(
            '@id' => $order->order_id,
            '!req' => '<pre>' . var_export($body, TRUE) . '</pre>',
            '!resp' => '<pre>' . var_export($response, TRUE) . '</pre>',
            ), WATCHDOG_ERROR);
          return;
        }
      }
      else {
        drupal_set_message(t("Avatax didn't get any response."), 'error');
        watchdog('uc_avatax', "Failed to void order @id - Avatax didn't respond.", array('@id' => $order->order_id), WATCHDOG_ERROR);
        return;
      }
      break;
  }
}
