<?php

/**
 * @file
 * Admin settings for uc_avatax.
 *
 * Copyright (C) Alexander Bischoff, adTumbler.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 */

/**
 * Admin settings menu callback.
 */
function uc_avatax_ui_admin_settings() {
  $form = array();

  $form['uc_avatax_product_version'] = array(
    '#title' => t('AvaTax Version'),
    '#description' => t('Select AvaTax Basic or AvaTax Pro according to your AvaTax Account License'),
    '#type' => 'select',
    '#options' => array(
      UC_AVATAX_TRIAL_VERSION => t('AvaTax Trial'),
      UC_AVATAX_BASIC_VERSION => t('AvaTax Basic'),
      UC_AVATAX_PRO_VERSION => t('AvaTax Pro'),
    ),
    '#default_value' => variable_get('uc_avatax_product_version', UC_AVATAX_TRIAL_VERSION),
  );

  $vids = array('nr', 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
                 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30);

  $form['uc_avatax_taxonomy_vid'] = array(
    '#title' => t('Sales Tax Taxonomy'),
    '#description' => t('Pro mode only - leave as "nr" (not required) unless selecting Pro mode'),
    '#type' => 'select',
    '#options' => $vids,
    '#default_value' => variable_get('uc_avatax_taxonomy_vid', array()),
  );

  $form['uc_avatax_use_mode'] = array(
    '#title' => t('AvaTax Mode'),
    '#description' => t('Only select Production if you have completed the GO LIVE process with Avalara'),
    '#type' => 'select',
    '#options' => array(
      'Development' => t('Development'),
      'Production' => t('Production')),
    '#default_value' => variable_get('uc_avatax_use_mode', 'Development'),
  );

  $form['uc_avatax_company_code'] = array(
    '#title' => t('Company Code'),
    '#description' => t('Enter the Company Code found under Organization in your AvaTax Dashboard'),
    '#type' => 'textfield',
    '#default_value' => variable_get('uc_avatax_company_code', ''),
  );

  $states = array(
    'AL' => t('Alabama'),
    'AK' => t('Alaska'),
    'AZ' => t('Arizona'),
    'AR' => t('Arkansas'),
    'CA' => t('California'),
    'CO' => t('Colorado'),
    'CT' => t('Connecticut'),
    'DE' => t('Delaware'),
    'DC' => t('District Of Columbia'),
    'FL' => t('Florida'),
    'GA' => t('Georgia'),
    'HI' => t('Hawaii'),
    'ID' => t('Idaho'),
    'IL' => t('Illinois'),
    'IN' => t('Indiana'),
    'IA' => t('Iowa'),
    'KS' => t('Kansas'),
    'KY' => t('Kentucky'),
    'LA' => t('Louisiana'),
    'ME' => t('Maine'),
    'MD' => t('Maryland'),
    'MA' => t('Massachusetts'),
    'MI' => t('Michigan'),
    'MN' => t('Minnesota'),
    'MS' => t('Mississippi'),
    'MO' => t('Missouri'),
    'MT' => t('Montana'),
    'NE' => t('Nebraska'),
    'NV' => t('Nevada'),
    'NH' => t('New Hampshire'),
    'NJ' => t('New Jersey'),
    'NM' => t('New Mexico'),
    'NY' => t('New York'),
    'NC' => t('North Carolina'),
    'ND' => t('North Dakota'),
    'OH' => t('Ohio'),
    'OK' => t('Oklahoma'),
    'OR' => t('Oregon'),
    'PA' => t('Pennsylvania'),
    'RI' => t('Rhode Island'),
    'SC' => t('South Carolina'),
    'SD' => t('South Dakota'),
    'TN' => t('Tennessee'),
    'TX' => t('Texas'),
    'UT' => t('Utah'),
    'VT' => t('Vermont'),
    'VA' => t('Virginia'),
    'WA' => t('Washington'),
    'WV' => t('West Virginia'),
    'WI' => t('Wisconsin'),
    'WY' => t('Wyoming'),
    'AA' => t('Armed Forces (Americas)'),
    'AE' => t('Armed Forces (Europe, Canada, Middle East, Africa)'),
    'AP' => t('Armed Forces (Pacific)'),
    'AS' => t('American Samoa'),
    'FM' => t('Federated States of Micronesia'),
    'GU' => t('Guam'),
    'MH' => t('Marshall Islands'),
    'MP' => t('Northern Mariana Islands'),
    'PW' => t('Palau'),
    'PR' => t('Puerto Rico'),
    'VI' => t('Virgin Islands'),
  );

  // Limit the list of states to use AvaTax for sales tax calculations.
  $form['uc_avatax_select_states'] = array(
    '#title' => t('AvaTax Selected States'),
    '#description' => t('Leave blank for AvaTax in ALL states (usual) - or select to limited States'),
    '#type' => 'select',
    '#multiple' => TRUE,
    '#options' => $states,
    '#default_value' => variable_get('uc_avatax_select_states', array()),
  );

  // Set AvaTax license details.
  $form['uc_avatax_account'] = array(
    '#title' => t('AvaTax Account Number'),
    '#description' => t('Enter your AvaTax Account Number'),
    '#type' => 'textfield',
    '#default_value' => variable_get('uc_avatax_account', ''),
  );
  
    $form['uc_avatax_license'] = array(
    '#title' => t('AvaTax License Key'),
    '#description' => t('Enter the AvaTax License Key'),
    '#type' => 'textfield',
    '#default_value' => variable_get('uc_avatax_license', ''),
  );

  $taxable_address = array(
    'Billing' => t('Billing'),
    'Shipping' => t('Shipping'),
  );

  // Configure address to use for sales tax.
  $form['options']['shipping']['uc_avatax_tax_address'] = array(
    '#title' => t('AvaTax Taxable Address'),
    '#description' => t('Select Taxable address - Shipping if site sells physical'),
    '#type' => 'select',
    '#options' => $taxable_address,
    '#default_value' => variable_get('uc_avatax_tax_address', 'Billing'),
  );

  // Set Shipping Tax code to be used by AvaTax.
  $form['uc_avatax_shipcode'] = array(
    '#title' => t('AvaTax Shipping Code'),
    '#description' => t('The Sales Tax code to be used for Shipping'),
    '#type' => 'textfield',
    '#default_value' => variable_get('uc_avatax_shipcode', 'FR020100'),
  );

  // Set Sales Tax Descriptions to be shown to users.
  $form['uc_avatax_tax_description'] = array(
    '#title' => t('AvaTax Checkout Description'),
    '#description' => t('The Sales Tax description to be displayed on the order check out form'),
    '#type' => 'textfield',
    '#default_value' => variable_get('uc_avatax_tax_description', 'Sales Tax'),
  );

  $form['uc_avatax_show_loc'] = array(
    '#title' => t('Show location code'),
    '#description' => t('AvaTax Checkout Select Yes to include the City name in your Sales Tax description'),
    '#type' => 'select',
    '#options' => array('0' => t('No'), '1' => t('Yes')),
    '#default_value' => variable_get('uc_avatax_show_loc', '1'),
  );

  $form['uc_avatax_show_zero'] = array(
    '#title' => t('Show zero taxes'),
    '#description' => t('Select Yes to display a sales tax line for zero tax results'),
    '#type' => 'select',
    '#options' => array('0' => t('No'), '1' => t('Yes')),
    '#default_value' => variable_get('uc_avatax_show_zero', '1'),
  );

  // Set Sales Tax automatic commits.
  $form['uc_avatax_erp_status'] = array(
    '#title' => t('Automatic updates to AvaTax doc status'),
    '#description' => t('Select "Yes" to enable automatic updates to AvaTax doc status'),
    '#type' => 'select',
    '#options' => array('0' => t('No'), '1' => t('Yes')),
    '#default_value' => variable_get('uc_avatax_erp_status', FALSE),
  );

  // Set Street, City, County, State and Zip for Primary Business Location.
  $form['uc_avatax_primary_street1'] = array(
    '#title' => t('Primary Business Street 1'),
    '#description' => t('The Primary Street 1 your business is located in'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('uc_avatax_primary_street1', ''),
  );

  $form['uc_avatax_primary_street2'] = array(
    '#title' => t('Primary Business Street 2'),
    '#description' => t('The Primary Street 2 your business is located in'),
    '#type' => 'textfield',
    '#default_value' => variable_get('uc_avatax_primary_street2', ''),
  );

  $form['uc_avatax_primary_city'] = array(
    '#title' => t('Primary Business City'),
    '#description' => t('The primary City your business is located in'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('uc_avatax_primary_city', ''),
  );

  $form['uc_avatax_primary_state'] = array(
    '#title' => t('Primary Business State'),
    '#description' => t('The primary State your business is located in'),
    '#type' => 'select',
    '#required' => TRUE,
    '#options' => $states,
    '#default_value' => variable_get('uc_avatax_primary_state', ''),
  );

  $form['uc_avatax_primary_zip'] = array(
    '#title' => t('Primary Business Zip'),
    '#description' => t('The primary Zip code your business is located in. NB - Must be a Valid 5 digit zip'),
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('uc_avatax_primary_zip', ''),
  );

  // Sales Tax Exemption management.
  $form['uc_avatax_exemptions'] = array(
    '#title' => t('Use AvaTax for Sales Tax Exemptions'),
    '#description' => t('Leave as Yes - Future provision for a sales tax exemption management module'),
    '#type' => 'select',
    '#options' => array(FALSE => t('No'), TRUE => t('Yes')),
    '#default_value' => variable_get('uc_avatax_exemptions', TRUE),
  );

  return system_settings_form($form);
}
